This cell is employed for testing the loading of templates.

To avoid the unnecessary compilation of ion channel mechanisms, they have been deactivated in the hoc.

**Caution:** do not use this cell in scientific simulations.
